@@ -66,8 +66,8 @@ class MySQLConnection:
 		self._dbName = dbName
 		self._dbPW = dbPW
 		self._dbUsername = dbUsername
-
 		self._db_connect()
+		self._db.autocommit(True)
 
 	def __del__(self):
 		""" Destructor """
@@ -159,7 +159,7 @@ class MySQLConnection:
 			self._execute(cursor, sql, parms)
 			return cursor.lastrowid
 		finally:
-			if cursor: cursor.close()
+			if cursor: cursor.close() 
 
 		
 	def query_rowcount(self, sql, parms):
